# Vision-Language Utilities

***Working in progress. You may face inconsistencies and break-changes across different versions.***

<p align="center">
  <a href="https://www.python.org/">
    <image src="https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54" alt="Python"/>
  </a>
  <a href="https://pytorch.org/">
    <image src="https://img.shields.io/badge/PyTorch-%23EE4C2C.svg?style=for-the-badge&logo=PyTorch&logoColor=white" alt="PyTorch"/>
  </a>
  <a href="https://pypi.python.org/pypi/vlutils/">
    <image src="https://img.shields.io/pypi/status/vlutils.svg?style=for-the-badge&logo=pypi&labelColor=ffdd54" alt="PyPI status"/>
  </a>
  <a href="https://pypi.python.org/pypi/vlutils/">
    <image src="https://img.shields.io/pypi/v/vlutils.svg?style=for-the-badge&logo=pypi&labelColor=ffdd54" alt="PyPI version"/>
  </a>
</p>


<p align="center">
  <a href="https://pypi.python.org/pypi/vlutils/">
    <image src="https://img.shields.io/pypi/dm/vlutils.svg?style=for-the-badge&logo=pypi&labelColor=ffdd54&color=4fa5ec" alt="PyPI download month"/>
  </a>
  <a href="https://pypi.python.org/pypi/vlutils/">
    <image src="https://img.shields.io/pypi/l/vlutils.svg?style=for-the-badge&logo=pypi&labelColor=ffdd54&color=dddddd" alt="PyPI license"/>
  </a>
</p>


<p align="center">
  <a href="https://github.com/VL-Group/vlutils/commits/main">
    <image src="https://img.shields.io/github/commit-activity/m/VL-Group/vlutils?logo=github&style=for-the-badge" alt="Github commits"/>
  </a>
  <a href="https://github.com/VL-Group/vlutils/issues">
    <image src="https://img.shields.io/github/issues/VL-Group/vlutils?logo=github&style=for-the-badge" alt="Github issues"/>
  </a>
  <a href="https://github.com/VL-Group/vlutils/pulls">
    <image src="https://img.shields.io/github/issues-pr/VL-Group/vlutils?logo=github&style=for-the-badge" alt="Github pull requests"/>
  </a>
</p>


A tool for convenient pytorch-based deep learning.
